# Music Assistant Client

Python client to interact with the Music Assistant Server API

---

[![A project from the Open Home Foundation](https://www.openhomefoundation.org/badges/ohf-project.png)](https://www.openhomefoundation.org/)
